import numpy as np
import pandas as pd
import matplotlib.pyplot as plt

# %%
data = pd.read_table('mc_out.dat', sep='\s+')

names = {
    'mu_0': 'k_alg_growth_max',
    'f_si': 'frac_si_alg_1',
    'lambda_S': 'k_att_shade',
    'K_light': 'k_light_sm',
    'sigma_0': 'k_alg_loss',
    'a': 'coeff_d_loss_2'
}

# %%
bins = {}
bins['mu_0'] = np.linspace(0.0, 5.4, 10)
bins['lambda_S'] = np.linspace(0.0, 0.045, 10)
bins['K_light'] = np.linspace(0.0, 450, 10)
bins['f_Si'] = np.linspace(0.0, 0.36, 10)
bins['sigma_0'] = np.linspace(0.0, 0.36, 10)
bins['a'] = np.linspace(1.1, 1.9, 10)
# %%

nmax = -1
skip = 100

dat = {}
for n in names:
    dat[n] = data[names[n]][:nmax:skip]


# see https://stackoverflow.com/questions/14306986/how-to-put-more-whitespace-around-my-plots
def histplot(key, condi=None):
    fig = plt.gcf()
    top_offset = .07
    left_offset = .15
    right_offset = .2
    bottom_offset = .13
    hgap = .1
    ax_width = 1-left_offset - right_offset
    ax_height = (1-top_offset - bottom_offset - hgap)/2
    ax1 = fig.add_axes([left_offset, bottom_offset + ax_height + hgap, ax_width, ax_height])
    ax = fig.add_axes([left_offset, bottom_offset, ax_width, ax_height])
    if condi is None:
        ax.hist(dat[key], bins[key], orientation='horizontal', density=True,
                 rwidth=0.5, color='k')
    else:
        ax.hist(dat[key][condi], bins[key], orientation='horizontal', density=True,
                 rwidth=0.5, color='k')

    ax.invert_yaxis()
    dbin = bins[key][1] - bins[key][0]
    binmid = bins[key][:-1] + 0.5*dbin
    plt.yticks(binmid)
    ax.set_yticklabels(
        ['{} - {}'.format(bins[key][k], bins[key][k+1])
         for k in range(len(bins[key])-1)]
    )
    ax.text(-30, binmid[0], '123')

plt.figure()
histplot('lambda_S')

# %%
cond = []
cond.append(
    np.logical_and(dat['mu_0'] >= bins['mu_0'][1],
                   dat['mu_0'] < bins['mu_0'][2])
)


plt.figure()
histplot('lambda_S', cond[0])
# %%
