import pandas as pd
from plot_hist_common import *
from profit.ui.hist_utils import fig_hist, dens_hist, format_hist
import plotly.graph_objects as go

densities = {
    'mu_0': (0.18, 19.6, 32.4, 19.4, 9.99, 5.56, 3.52, 2.44, 1.79, 5.13),
    'lambda_S': (1.67, 12.4, 37.0, 22.4, 10.1, 5.27, 3.24, 2.22, 1.60, 4.13),
    'K_light': (18.3, 33.9, 22.0, 11.4, 6.11, 3.46, 1.99, 1.20, 0.69, 0.98),
    'f_Si': (0.011, 2.18, 13.1, 22.7, 25.2, 20.2, 11.6, 4.16, 0.78, 0.072),
    'sigma_0': (11.0, 22.5, 21.3, 16.3, 10.9, 7.35, 4.61, 2.62, 1.43, 1.95),
    'a': (0.86, 14.7, 29.6, 23.7, 14.0, 7.58, 4.06, 2.24, 1.26, 2.01) 
}

densities2 = {
    'mu_0': (0, 0, 0, 0, 100, 0, 0, 0, 0, 0),
    'lambda_S': (0.004, 3.48, 46.1, 33.2, 10.7, 4.26, 1.45, 0.50, 0.18, 0.17),
    'K_light': (4.93, 25.4, 40.3, 23.6, 5.13, 0.59, 0.055, 0.028, 0.024, 0.022),
    'f_Si': (0, 0, 100, 0, 0, 0, 0, 0, 0, 0),
    'sigma_0': (0, 0.001, 0.011, 0.62, 9.85, 29.0, 30.7, 18.5, 8.14, 3.16),
    'a': (2.76, 46.8, 43.9, 6.13, 0.36, 0.018, 0.006, 0.006, 0.006, 0.006) 
}

data = pd.read_table('mc_out.dat', sep=r'\s+')

nmax = -1
skip = 1
dat = {}
for n in names:
    dat[n] = data[names[n]][:nmax:skip]

cond = get_cond(dat)

colors['mu_0'] = ('#a0a0a0', '#c8c8c8')
colors['f_Si'] = ('#a0a0a0', '#c8c8c8')
for key in names:
    den1, edges = dens_hist(dat[key], bins[key], outside[key])    
    den2, edges2 = dens_hist(dat[key][cond[2]], bins[key], outside[key])

    density = densities[key]
    density2 = densities2[key]

    bar1 = go.Bar(
        y=edges2, x=density2, orientation='h',
        marker=dict(color='black', line=dict(color='black'))
    )
    bar2 = go.Bar(
        y=edges, x=density, orientation='h',
        marker=dict(
            color='rgba(0,0,0,0)',
            line=dict(color='white', width=1)
        )
    )
    fig = go.Figure(data=[bar1, bar2])

    format_hist(fig, bins[key], edges2, density2, title[key], outside[key], colors[key])

    fig.write_image(f'fig8_{key}.pdf')
